@@ -301,8 +301,9 @@ class CommonQuerySet(QuerySet):
         delAttr(_data, 'guid')
         for key, value in data.items():
             if key.find('__id') == -1 and key.find('_id') != -1:
-                delAttr(_data, key)
-                setAttr(_data, key.replace('_id', '__id'), value)
+                if len([item.name for item in self.model._meta.fields if item.name == key]) == 0:
+                    delAttr(_data, key)
+                    setAttr(_data, key.replace('_id', '__id'), value)
             elif isinstance(value, str) and value.strip() == '':
                 delAttr(_data, key)
 
